@@ -21,6 +21,34 @@ our $VERSION = 0.01;
     my $perl  = $coder->decode( $json );
     my $from  = $params->{from};
     
+    if ( $url =~ /get-balance/ ) {
+        $from = 'get-balance';
+        $url  = 'get-balance';
+    }
+    
+    my $subhash   = $perl->{$url}->{$from};
+    my $response  = $coder->encode( $subhash );
+    
+    my $http_response = HTTP::Response->new( 200 );
+    $http_response->content( $response );
+    
+    return $http_response;
+};
+
+*LWP::UserAgent::get = sub {
+    my ($object,$url,$params) = @_;
+    
+    my $json = do{ undef $/; <DATA> };
+    
+    my $coder = JSON::PP->new->ascii->pretty->allow_nonref;
+    my $perl  = $coder->decode( $json );
+    my $from  = $params->{from};
+    
+    if ( $url =~ /get-balance/ ) {
+        $from = 'get-balance';
+        $url  = 'get-balance';
+    }
+    
     my $subhash   = $perl->{$url}->{$from};
     my $response  = $coder->encode( $subhash );
     
@@ -43,7 +71,7 @@ Nexmo::SMS::MockLWP
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -158,5 +186,10 @@ __DATA__
               }
             ]
         }
+    },
+    "get-balance" : {
+        "get-balance" : {
+            "value" : 4.15
+        }
     }
 }
\ No newline at end of file
